.. -*- mode: rst; fill-column: 79; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the niceman package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. _chap_glossary:

********
Glossary
********

NICEMAN uses terminology which is collated from various technologies. This
glossary provides definitions for terms used in the NICEMAN documentation
and API, and provides additional references where to seek more information

.. glossary::
  :sorted:

  container
    TODO   Docker_ and Singularity_

  package
    TODO

  environment
    TODO

  virtual machine
    TODO

  cloud instance
    TODO

.. _Docker: http://docker.io
.. _Singularity: http://singularity.lbl.gov